@@ -110,6 +110,7 @@ void c_get_screen_info(char *fb_file) {
     Inline_Stack_Push(sv_2mortal(newSVnv(vinfo.rotate)));
 
     Inline_Stack_Done;
+    // Phew!
 }
 
 // Sets the framebuffer to text mode, which enables the cursor
@@ -128,7 +129,6 @@ void c_graphics_mode(char *tty_file)
    close(tty_fd);
 }
 
-
 /* The other routines call this.  It handles all draw modes
  * 
  * Normally I would add code to properly place the RGB values according to
@@ -172,6 +172,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) = (short) color; // 16 bit can send a word at a time, the second most efficient method.
                         }
+				        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -193,6 +197,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) ^= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -214,6 +222,10 @@ void c_plot(
                         {
                            *((unsigned short*)(framebuffer + index)) |= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -235,6 +247,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) &= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -262,6 +278,10 @@ void c_plot(
                                 *((unsigned short*)(framebuffer + index )) = color;
                             }
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -290,6 +310,10 @@ void c_plot(
                              }
                          }
                          break;
+				    case 8 :
+				        break;
+                    case 1 :
+                        break;
                 }
             break;
             case ALPHA_MODE :
@@ -348,6 +372,10 @@ void c_plot(
                             rgb565 = (fb_b << 11) | (fb_g << 5) | fb_r;
                             *((unsigned short*)(framebuffer + index)) = rgb565;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -369,6 +397,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) += (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -390,6 +422,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) -= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -411,6 +447,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) *= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
@@ -432,6 +472,10 @@ void c_plot(
                         {
                             *((unsigned short*)(framebuffer + index)) /= (short) color;
                         }
+                        break;
+				    case 8 :
+				        break;
+                    case 1 :
                         break;
                 }
             break;
